AiEvent class

Timestamped event emitted during a run.

Constructors

AiEvent({required String type, required DateTime timestamp, Map<String, dynamic> payload = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
payload Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the event into a persistence-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited