AiGoal class

High-level task submitted to an agent.

Constructors

AiGoal({required String task, Map<String, dynamic> input = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
input Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
task String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the goal into a persistence-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited