AiHttpClient class abstract
Contract for HTTP clients used by AI providers.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
send(
AiHttpRequest request) → Future< AiHttpResponse> -
stream(
AiHttpRequest request) → Stream< String> - Sends a request and yields decoded text chunks as they arrive.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited