AiHttpRequest class

Immutable outbound AI HTTP request.

Constructors

AiHttpRequest({required String method, required Uri uri, Map<String, String> headers = const {}, Object? body})
const

Properties

body Object?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
method String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited