AiHttpResponse class

Immutable AI HTTP response wrapper.

Constructors

AiHttpResponse({required int statusCode, Map<String, String> headers = const {}, String body = ''})
const

Properties

body String
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>
final
isSuccess bool
Whether the response status is in the 2xx range.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

jsonBody() → dynamic
Decodes the response body as JSON.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited