AiMemoryStore class abstract

Contract for AI run-event and thread-message memory storage.

Implementers

Constructors

AiMemoryStore()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendRunEvent(String runId, Map<String, dynamic> event) Future<void>
loadRunEvents(String runId) Future<List<Map<String, dynamic>>>
loadThreadMessages(String threadId) Future<List<Map<String, dynamic>>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveThreadMessage(String threadId, Map<String, dynamic> message) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited