AiPlan class

Ordered collection of steps produced by a planner.

Constructors

AiPlan({required List<AiPlanStep> steps, Map<String, dynamic> metadata = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps List<AiPlanStep>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the plan into a persistence-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited