AiPlanStep class

A single executable step in an AI plan.

Constructors

AiPlanStep({required String id, required String type, required String description, String? toolName, Map<String, dynamic> arguments = const {}})
const

Properties

arguments Map<String, dynamic>
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolName String?
final
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the step into a persistence-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited