AiRun class

Mutable state container for an individual agent execution.

Constructors

AiRun({required String id, required String agentName, required AiGoal goal, String? userId, String? tenantId, String? threadId, AiRunStatus status = AiRunStatus.pending, Map<String, dynamic>? state, List<AiEvent>? events, Map<String, dynamic>? output})

Properties

agentName String
final
events List<AiEvent>
final
goal AiGoal
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
output Map<String, dynamic>?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Map<String, dynamic>
final
status AiRunStatus
getter/setter pair
tenantId String?
final
threadId String?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the run into a persistence-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited