AiRunResult class

Final output of an agent run.

Constructors

AiRunResult({required AiRun run, required Map<String, dynamic> output})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
output Map<String, dynamic>
final
run AiRun
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the run result into a persistence-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited