AiTool class abstract

Contract implemented by executable AI tools.

Constructors

AiTool()

Properties

description String
Human-readable tool description.
no setter
enabledByDefault bool
Whether the tool is allowed by the safe default policy.
no setter
hashCode int
The hash code for this object.
no setterinherited
name String
Stable tool name used in plans and policies.
no setter
requiredCapabilities Set<String>
Named capabilities required by this tool.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe() Map<String, dynamic>
Returns a serializable description of the tool.
execute(AiToolContext context) Future<Map<String, dynamic>>
Executes the tool call for the supplied context.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited