enabledByDefault property
bool
get
enabledByDefault
Whether the tool is allowed by the safe default policy.
Implementation
bool get enabledByDefault => false;
Whether the tool is allowed by the safe default policy.
bool get enabledByDefault => false;