AiToolContext class

Context passed into tool execution.

Constructors

AiToolContext({required String runId, required Map<String, dynamic> state, required Map<String, dynamic> arguments, String? userId, String? tenantId, Context? context, Map<String, dynamic> metadata = const {}, Map<String, dynamic> artifacts = const {}})
const

Properties

arguments Map<String, dynamic>
final
artifacts Map<String, dynamic>
final
context Context?
final
hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
final
runId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
state Map<String, dynamic>
final
tenantId String?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited