AiToolPolicy class abstract
Contract for authorizing tool execution.
Implement this when your app needs custom authorization, approval queues, or tenant-specific tool rules.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canExecute(
AiToolInvocation invocation) → Future< bool> -
Returns whether
invocationmay execute. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited