AiWorkflowRegistry class

Registry for named workflows.

Constructors

AiWorkflowRegistry()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describeAll() List<Map<String, dynamic>>
Returns descriptions for all registered workflows.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(AiWorkflow workflow) → void
Registers a workflow by name.
toString() String
A string representation of this object.
inherited
workflow(String name) AiWorkflow?
Looks up a workflow by name.

Operators

operator ==(Object other) bool
The equality operator.
inherited