AiWorkflowRunResult class

Result wrapper returned by FlintAi.runWorkflow.

Constructors

AiWorkflowRunResult({required String workflowName, required Map<String, dynamic> output})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
output Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
workflowName String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the workflow result into a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited