AutoAiMemoryStore class

Memory store that prefers the database and falls back to memory with warnings.

Implemented types

Constructors

AutoAiMemoryStore({AiMemoryStore? primary, InMemoryAiMemoryStore? fallback})

Properties

fallback InMemoryAiMemoryStore
final
hashCode int
The hash code for this object.
no setterinherited
primary AiMemoryStore
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

appendRunEvent(String runId, Map<String, dynamic> event) Future<void>
override
loadRunEvents(String runId) Future<List<Map<String, dynamic>>>
override
loadThreadMessages(String threadId) Future<List<Map<String, dynamic>>>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveThreadMessage(String threadId, Map<String, dynamic> message) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited