AutoAiRepository class

Default repository used by the standalone package.

Apps and frameworks can inject durable implementations for database or object-storage persistence.

Inheritance

Constructors

AutoAiRepository({InMemoryAiRunStore? runs, InMemoryAiThreadStore? threads, InMemoryAiTraceStore? traces, InMemoryAiArtifactStore? artifacts})
factory

Properties

artifacts AiArtifactStore?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
memoryArtifacts InMemoryAiArtifactStore
final
memoryRuns InMemoryAiRunStore
final
memoryThreads InMemoryAiThreadStore
final
memoryTraces InMemoryAiTraceStore
final
runs AiRunStore?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threads AiThreadStore?
finalinherited
traces AiTraceStore?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited