BasicTaskAgent class

Minimal example agent that copies the incoming goal into run state.

Inheritance

Constructors

BasicTaskAgent({String name = 'basic_task_agent'})

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Stable agent name used in runs and logs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
plan(AiRunContext context) Future<AiPlan>
Produces an execution plan for the current run context.
override
synthesize(AiRunContext context) Future<Map<String, dynamic>>
Produces the final structured output after plan execution.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited