ChatRequest class

Input payload for a chat completion request.

Constructors

ChatRequest({required String model, required List<ChatMessage> messages, double? temperature, int? maxTokens, Map<String, dynamic> metadata = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
maxTokens int?
final
messages List<ChatMessage>
final
metadata Map<String, dynamic>
final
model String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temperature double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited