ChatResult class

Non-streaming chat completion result.

Constructors

ChatResult({required String providerId, required String model, required String content, ChatUsage usage = const ChatUsage(), Map<String, dynamic> raw = const {}})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setterinherited
model String
final
providerId String
final
raw Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
usage ChatUsage
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the result into a persistence-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited