ChatUsage class

Token usage metadata returned by a provider.

Constructors

ChatUsage({int? inputTokens, int? outputTokens, int? totalTokens})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
inputTokens int?
final
outputTokens int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTokens int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes usage into a persistence-friendly map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited