DefaultAiPlanner class

Default planner that delegates planning to the agent itself.

Implemented types

Constructors

DefaultAiPlanner()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPlan(AiAgent agent, AiRunContext context) Future<AiPlan>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited