EmbeddingResult class

Result payload for an embedding request.

Constructors

EmbeddingResult({required String providerId, List<double> vector = const [], Map<String, dynamic> raw = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
providerId String
final
raw Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vector List<double>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
Serializes the embedding result into a map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited