InMemoryAiArtifactStore class

In-memory artifact store for development and tests.

Implemented types

Constructors

InMemoryAiArtifactStore()

Properties

artifacts List<Map<String, dynamic>>
Returns all stored artifacts.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveArtifact(Map<String, dynamic> artifact) Future<void>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited