RetryingAiHttpClient class

HTTP client wrapper that retries transient provider failures.

Implemented types

Constructors

RetryingAiHttpClient(AiHttpClient inner, {AiRetryPolicy retryPolicy = const AiRetryPolicy()})

Properties

hashCode int
The hash code for this object.
no setterinherited
inner AiHttpClient
final
retryPolicy AiRetryPolicy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(AiHttpRequest request) Future<AiHttpResponse>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited