SafeDefaultAiToolPolicy class

Safe default policy that only allows explicitly approved tools.

Implemented types

Constructors

SafeDefaultAiToolPolicy({Set<String> allowedTools = const {}, bool requireUserBinding = false})
const

Properties

allowedTools Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
requireUserBinding bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

canExecute(AiToolInvocation invocation) Future<bool>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited