AuthVerification extension

Backward-compatible extension wrappers.

The source of truth for verification/reset flows is now Auth to avoid drift between duplicated implementations.

on

Static Methods

generateNumericVerificationCode(String email, {int length = 6}) → Future<String>

Available on Auth, provided by the AuthVerification extension

generatePasswordResetCode(String email, {int length = 6}) → Future<String>

Available on Auth, provided by the AuthVerification extension

resendPasswordResetCode(String email) → Future<String>

Available on Auth, provided by the AuthVerification extension

resendVerificationCode(String email) → Future<String>

Available on Auth, provided by the AuthVerification extension

resetPasswordWithCode({required String email, required String code, required String newPassword}) → Future<bool>

Available on Auth, provided by the AuthVerification extension

verifyNumericCode(String email, String code) → Future<bool>

Available on Auth, provided by the AuthVerification extension

verifyPasswordResetCode({required String email, required String code}) → Future<bool>

Available on Auth, provided by the AuthVerification extension