AiRetryPolicy class

Retry configuration for provider HTTP requests.

Constructors

AiRetryPolicy({int maxAttempts = 3, Duration baseDelay = const Duration(milliseconds: 200), bool shouldRetryResponse(AiHttpResponse response) = _defaultRetryResponse, bool shouldRetryError(Object error) = _defaultRetryError})
const

Properties

baseDelay Duration
final
hashCode int
The hash code for this object.
no setterinherited
maxAttempts int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldRetryError bool Function(Object error)
final
shouldRetryResponse bool Function(AiHttpResponse response)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited