ControllerRouteBuilder<T extends Controller> class

Constructors

ControllerRouteBuilder(Flint _app, ControllerFactory<T> _factory)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete(String path, ControllerCallback<T> action) → RouteBuilder
get(String path, ControllerCallback<T> action) → RouteBuilder
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch(String path, ControllerCallback<T> action) → RouteBuilder
post(String path, ControllerCallback<T> action) → RouteBuilder
put(String path, ControllerCallback<T> action) → RouteBuilder
route(String method, String path, ControllerCallback<T> action) → RouteBuilder
toString() String
A string representation of this object.
inherited
websocket(String path, void action(T controller), {List<Middleware> middlewares = const []}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited