CorsMiddleware class

Inheritance

Constructors

CorsMiddleware({List<String> allowedOrigins = const ['*'], List<String> allowedMethods = const ['GET', 'POST', 'PUT', 'DELETE', 'OPTIONS', 'PATCH'], List<String> allowedHeaders = const ['Content-Type', 'Authorization']})

Properties

allowedHeaders List<String>
final
allowedMethods List<String>
final
allowedOrigins List<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(Handler next) Handler
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited