EmbeddingProvider class abstract

Contract for embedding-capable AI providers.

Constructors

EmbeddingProvider()

Properties

displayName String
Human-readable provider name.
no setter
hashCode int
The hash code for this object.
no setterinherited
id String
Stable provider id used for registration and lookup.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

describe() Map<String, dynamic>
Returns a serializable description of the provider.
embed(EmbeddingRequest request) Future<EmbeddingResult>
Generates an embedding vector for the supplied request.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited