FlintJobContext class

Constructors

FlintJobContext({required FlintJobStore store, required FlintJobRecord record, required int attempt})

Properties

attempt int
final
finished bool
no setter
hashCode int
The hash code for this object.
no setterinherited
payload Map<String, dynamic>
final
record FlintJobRecord
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

complete({Map<String, dynamic>? payload}) Future<void>
fail(Object error, {bool retry = true}) Future<void>
log(String message, {Map<String, dynamic>? metadata}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release({required DateTime nextRunAt, String? reason}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited