FlintJobRunRecord class

Constructors

FlintJobRunRecord({required String id, required String jobId, required String type, required String queue, required String status, required int attempt, required DateTime startedAt, DateTime? finishedAt, int? elapsedMs, String? error, String? workerId, Map<String, dynamic> metadata = const {}})
const

Properties

attempt int
final
elapsedMs int?
final
error String?
final
finishedAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
jobId String
final
metadata Map<String, dynamic>
final
queue String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt DateTime
final
status String
final
type String
final
workerId String?
final

Methods

copyWith({String? id, String? jobId, String? type, String? queue, String? status, int? attempt, DateTime? startedAt, DateTime? finishedAt, int? elapsedMs, String? error, bool clearError = false, String? workerId, Map<String, dynamic>? metadata}) FlintJobRunRecord
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited