FlintJwt class

Constructors

FlintJwt(String secretKey)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secretKey String
final

Methods

generateToken(Map<String, dynamic> payload, {Duration expiry = const Duration(hours: 1)}) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
verifyToken(String token) Map<String, dynamic>?

Operators

operator ==(Object other) bool
The equality operator.
inherited