ImageGenerationRequest class

Input payload for an image generation request.

Constructors

ImageGenerationRequest({required String prompt, String? model, String? size, Map<String, dynamic> metadata = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
final
model String?
final
prompt String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited