Index class

Represents an index on one or more columns in a table.

Constructors

Index({required String name, required List<String> columns, bool isUnique = false})
Creates a new Index definition.

Properties

columns List<String>
The columns included in the index.
final
hashCode int
The hash code for this object.
no setterinherited
isUnique bool
Whether the index enforces uniqueness.
final
name String
The name of the index.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited