MemoryCacheStore class

In-memory cache implementation

Implemented types

Constructors

MemoryCacheStore({int maxSize = 100})

Properties

hashCode int
The hash code for this object.
no setterinherited
maxSize int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cleanup(DateTime before) Future<void>
override
clear() Future<void>
override
delete(String key) Future<void>
override
get<T>(String key) Future<CachedResponse<T>?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set<T>(String key, CachedResponse<T> response) Future<void>
override
size() Future<int>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited