RequestOptions<T> class

Constructors

RequestOptions({dynamic body, Map<String, dynamic>? queryParameters, Map<String, String>? headers, String? saveFilePath, Map<String, File>? files, void onSendProgress(int sent, int total)?, StatusCodeConfig? statusConfig, CacheConfig? cacheConfig, RetryConfig? retryConfig, T parser(dynamic data)?, void onError(FlintError error)?, void onDone(FlintResponse<T> response, FlintError? error)?, CancelToken? cancelToken, Duration? timeout, RequestContext? context, ResponseParseMode? parseMode})
const

Properties

body → dynamic
final
cacheConfig CacheConfig?
final
cancelToken CancelToken?
final
context RequestContext?
final
files Map<String, File>?
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, String>?
final
onDone → void Function(FlintResponse<T> response, FlintError? error)?
final
onError → void Function(FlintError error)?
final
onSendProgress → void Function(int sent, int total)?
final
parseMode ResponseParseMode?
final
parser → T Function(dynamic data)?
final
queryParameters Map<String, dynamic>?
final
retryConfig RetryConfig?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
saveFilePath String?
final
statusConfig StatusCodeConfig?
final
timeout Duration?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited