Router class

Constructors

Router()

Properties

hashCode int
The hash code for this object.
no setterinherited
routes List<Route>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

add(String method, String path, Object handler, {List<Middleware> middlewares = const []}) → void
match(String method, String pathToMatch, Map<String, String> paramsOut) Handler?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited