Seeder class abstract

Base contract for framework-level database seeders.

Constructors

Seeder()

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Human-readable seeder name used in logs.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
run() Future<void>
Executes the seeder logic.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited