StaticFileMiddleware class

Inheritance

Constructors

StaticFileMiddleware({String publicFolder = 'public', Duration cacheDuration = const Duration(days: 30), int maxFileSize = 100 * 1024 * 1024, bool enableCompression = true, bool enableRangeRequests = true})

Properties

cacheDuration Duration
final
enableCompression bool
final
enableRangeRequests bool
final
hashCode int
The hash code for this object.
no setterinherited
maxFileSize int
final
publicFolder String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

handle(Handler next) Handler
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited