UploadedFile class

Constructors

UploadedFile({required String fieldName, required String filename, String? contentType, int? size, String? extension, DateTime? uploadedAt, required Stream<List<int>> content})

Properties

content Stream<List<int>>
final
contentType String?
final
extension String?
final
fieldName String
final
filename String
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
final
uploadedAt DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
saveTo(String path) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited