WebSocketManager class

Constructors

WebSocketManager()
factory

Properties

clients Map<String, FlintWebSocket>
no setter
hashCode int
The hash code for this object.
no setterinherited
rooms Map<String, Set<FlintWebSocket>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addClient(String id, FlintWebSocket client) → void
addToRoom(String namespace, String room, FlintWebSocket client) → void
debugPrintStatus() → void
emit(String room, String event, dynamic data, {String namespace = '/'}) → void
emitToAll(String event, dynamic data) → void
emitToClient(String clientId, String event, dynamic data) → void
emitToNamespace(String namespace, String event, dynamic data, {String? excludeClientId}) → void
emitToPathRoom(String namespace, String room, String event, dynamic data, {String? excludeClientId}) → void
emitToRoom(String room, String event, dynamic data, {String namespace = '/'}) → void
namespaceClients(String namespace) Iterable<FlintWebSocket>
normalizeNamespace(String namespace) String
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeClient(String id) → void
removeFromRoom(String namespace, String room, FlintWebSocket client) → void
roomClients(String namespace, String room) Set<FlintWebSocket>?
scopeRoom(String namespace, String room) String
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance WebSocketManager
no setter