AnimationDirection class

CSS animation-direction value.

Constructors

AnimationDirection(String value)
Creates an animation direction value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS animation-direction string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS animation-direction string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited