AnimationIteration class

CSS animation-iteration-count value.

Constructors

AnimationIteration(Object value)
Creates an animation iteration value.
const
AnimationIteration.count(num count)
Creates a numeric iteration count.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object
Iteration count or keyword.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS animation-iteration-count string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

infinite → const AnimationIteration
CSS infinite iteration count.