AnimationPlayState class

CSS animation-play-state value.

Constructors

AnimationPlayState(String value)
Creates an animation play state value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS animation-play-state string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS animation-play-state string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

paused → const AnimationPlayState
running → const AnimationPlayState