AspectRatioBox class
Box that preserves a CSS aspect ratio.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- AspectRatioBox
Constructors
-
AspectRatioBox({required Object ratio, Object? child, List<
Object?> children = const [], Object? width, Object? overflow, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) -
Creates an aspect-ratio box from
ratio. -
AspectRatioBox.square({Object? child, List<
Object?> children = const [], Object? width, Object? overflow, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) - Creates a square aspect-ratio box.
-
AspectRatioBox.video({Object? child, List<
Object?> children = const [], Object? width, Object? overflow, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) - Creates a 16:9 aspect-ratio box.
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited