Audio class
Native HTML audio element with Flint styling and media controls.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- Audio
Constructors
-
Audio({MediaElementController? controller, String? src, bool controls = true, bool autoplay = false, bool muted = false, bool loop = false, MediaPreload preload = MediaPreload.metadata, String? crossOrigin, String? className, Object? fallback, Map<
String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) - Creates an audio element for URL/file-based audio playback.
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited