Background class

CSS background value that can combine multiple layers.

Constructors

Background(String value)
Creates a background from a raw CSS value.
const
Background.layers(List<Object> layers)
Creates a comma-separated layered background.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS background string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS background string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited