BoxSizing class

CSS box-sizing value.

Constructors

BoxSizing(String value)
Creates a box-sizing value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS box-sizing string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS box-sizing string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

borderBox → const BoxSizing
CSS border-box.
contentBox → const BoxSizing
CSS content-box.