BreadcrumbItem class

Item rendered inside Breadcrumbs.

Constructors

Creates a breadcrumb item.
const

Properties

current bool
Whether this item represents the current page.
final
hashCode int
The hash code for this object.
no setterinherited
href String?
Optional destination URL.
final
label String
Visible breadcrumb label.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited