currentPath property
String
get
currentPath
The current browser path without query string or hash.
Implementation
String get currentPath => web.window.location.pathname;
The current browser path without query string or hash.
String get currentPath => web.window.location.pathname;