currentQuery property
String
get
currentQuery
The current browser query string, including the leading ?.
Implementation
String get currentQuery => web.window.location.search;
The current browser query string, including the leading ?.
String get currentQuery => web.window.location.search;