navigate method
void
navigate(
Pushes a new browser history entry without reloading the page.
Implementation
void navigate(String url, {Object? state}) {
web.window.history.pushState(_toJsState(state), '', url);
}
Pushes a new browser history entry without reloading the page.
void navigate(String url, {Object? state}) {
web.window.history.pushState(_toJsState(state), '', url);
}