CanvasAlignment enum

Alignment commands for selected canvas objects.

Inheritance
Available extensions

Values

left → const CanvasAlignment

Align selected objects to the left edge of the selection bounds.

center → const CanvasAlignment

Align selected objects to the horizontal center of the selection bounds.

Align selected objects to the right edge of the selection bounds.

top → const CanvasAlignment

Align selected objects to the top edge of the selection bounds.

middle → const CanvasAlignment

Align selected objects to the vertical middle of the selection bounds.

bottom → const CanvasAlignment

Align selected objects to the bottom edge of the selection bounds.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CanvasAlignment>
A constant List of the values in this enum, in order of their declaration.