CanvasBounds class

Axis-aligned bounds for a retained canvas object.

Constructors

CanvasBounds({required double x, required double y, required double width, required double height})
Creates canvas bounds.
const

Properties

bottom double
Bottom edge in canvas space.
no setter
centerX double
Horizontal center in canvas space.
no setter
centerY double
Vertical center in canvas space.
no setter
hashCode int
The hash code for this object.
no setterinherited
height double
Bounds height in canvas units.
final
left double
Left edge in canvas space.
no setter
Right edge in canvas space.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top double
Top edge in canvas space.
no setter
width double
Bounds width in canvas units.
final
x double
Left coordinate in canvas space.
final
y double
Top coordinate in canvas space.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited