CanvasCircle class
Retained circle object.
- Inheritance
-
- Object
- CanvasObject
- CanvasCircle
Constructors
- CanvasCircle({String? id, String? name, CanvasPaint paint = const CanvasPaint(), double rotation = 0, bool locked = false, required double x, required double y, required double radius})
-
Creates a circle.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether this object is hidden from drawing and pointer hit testing.
finalinherited
- id → String?
-
Optional app-level object identifier.
finalinherited
- locked → bool
-
Whether this object can be selected but not edited.
finalinherited
- name → String?
-
Optional display name for layer panels.
finalinherited
- paint → CanvasPaint
-
Paint settings for this object.
finalinherited
- radius → double
-
final
- rotation → double
-
Clockwise rotation in degrees.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
Object type name used for JSON serialization.
no setteroverride
- x → double
-
final
- y → double
-
final
Methods
-
copyWith(
{String? id, String? name, CanvasPaint? paint, double? rotation, bool? locked, double? x, double? y, double? radius}) → CanvasCircle - Creates a copy with selected values replaced.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
Converts this object to a JSON-friendly map.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited