isAttached property
bool
get
isAttached
Whether the controller is attached to a browser canvas.
Implementation
bool get isAttached => false;
Whether the controller is attached to a browser canvas.
bool get isAttached => false;