CanvasGuide class
Visual snap guide.
Constructors
- CanvasGuide({required CanvasGuideOrientation orientation, required double position})
-
Creates a visual snap guide.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- orientation → CanvasGuideOrientation
-
Guide orientation.
final
- position → double
-
Guide position in canvas space.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited