CanvasLayerItem class
Layer-panel metadata for a retained canvas object.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
Whether this layer is hidden from drawing and hit testing.
final
- id → String?
-
Object id, when the retained object has one.
final
- locked → bool
-
Whether this layer is locked against editing.
final
- name → String
-
Human-friendly layer name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selected → bool
-
Whether this layer is currently selected.
final
- type → String
-
Retained object type, such as
rect,text, orimage.final - zIndex → int
-
Zero-based object index in the retained scene.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited