CanvasPointerEvent class

Pointer event payload for browser canvas interactions.

Constructors

CanvasPointerEvent({required double x, required double y, CanvasObject? object, CanvasSelectionHandle? handle})
Creates a canvas pointer event payload.
const

Properties

handle CanvasSelectionHandle?
Selection handle under the pointer, when available.
final
hashCode int
The hash code for this object.
no setterinherited
object CanvasObject?
Topmost object under the pointer, when available.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
x double
Pointer x coordinate in canvas space.
final
y double
Pointer y coordinate in canvas space.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited