CapturedMedia class
Captured media ready for preview, upload, or storage.
Constructors
- CapturedMedia({required CapturedMediaKind kind, required String filename, required String mimeType, required int size, required String dataUrl, required String base64, Object? blob})
-
Creates a captured media value.
const
Properties
- base64 → String
-
Base64 payload without the
data:mime/type;base64,prefix.final - blob → Object?
-
Raw browser Blob in browser builds.
final
- dataUrl → String
-
Data URL containing the media payload.
final
- filename → String
-
Suggested filename for upload or download.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- kind → CapturedMediaKind
-
Captured media category.
final
- mimeType → String
-
Browser MIME type such as
image/png,audio/webm, orvideo/webm.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → int
-
Size in bytes when known.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toUploadBody(
{String filenameField = 'filename', String mimeTypeField = 'mime_type', String base64Field = 'base64', String typeField = 'type'}) → Map< String, Object?> - JSON-friendly upload body for Flint backend endpoints.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited