CardVariant enum
Visual variants for card-like surfaces.
Values
- outline → const CardVariant
-
Outlined card surface.
- elevated → const CardVariant
-
Elevated card surface with shadow.
- soft → const CardVariant
-
Soft tinted card surface.
- ghost → const CardVariant
-
Ghost card with transparent surface.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CardVariant> - A constant List of the values in this enum, in order of their declaration.