group method
Returns a new router with prefix appended to this router's prefix.
Implementation
ClientRouter group(String prefix) {
return ClientRouter.fromClient(client, prefix: _join(this.prefix, prefix));
}
Returns a new router with prefix appended to this router's prefix.
ClientRouter group(String prefix) {
return ClientRouter.fromClient(client, prefix: _join(this.prefix, prefix));
}