Color class

CSS color value used by typed Flint UI styles.

Constructors

Color(String value)
Creates a color from a raw CSS color value.
const
Color.hex(String value)
Creates a color from a hex string.
const
Color.rgb(int red, int green, int blue)
Creates an rgb(...) color.
const
Color.rgba(int red, int green, int blue, double alpha)
Creates an rgba(...) color.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS color string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS color string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited