Colors class

Built-in color tokens for Flint UI examples and components.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

black → const Color
blue50 → const Color
blue100 → const Color
blue200 → const Color
blue300 → const Color
blue400 → const Color
blue500 → const Color
blue600 → const Color
blue700 → const Color
blue800 → const Color
blue900 → const Color
cyan50 → const Color
cyan700 → const Color
rose50 → const Color
rose200 → const Color
rose700 → const Color
sky50 → const Color
sky100 → const Color
sky200 → const Color
sky300 → const Color
sky400 → const Color
sky500 → const Color
sky600 → const Color
sky700 → const Color
sky800 → const Color
sky900 → const Color
slate50 → const Color
slate100 → const Color
slate200 → const Color
slate300 → const Color
slate400 → const Color
slate500 → const Color
slate600 → const Color
slate700 → const Color
slate800 → const Color
slate900 → const Color
transparent → const Color
white → const Color