ConfirmAction class
Confirmation dialog for dangerous or deliberate user actions.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- ConfirmAction
Constructors
-
ConfirmAction({required bool open, required String title, required String message, String confirmLabel = 'Confirm', String cancelLabel = 'Cancel', bool danger = false, String? className, Map<
String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle, void onConfirm(Object event)?, void onCancel(Object event)?}) -
Creates a confirmation modal controlled by
open.
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited