Cookies class

Reads and writes browser cookies for Flint UI apps.

Constructors

Cookies()
Creates a browser cookie helper.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear({String path = '/'}) → void
Removes all currently visible cookies for path.
has(String name) bool
Whether a cookie named name is currently visible.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String name) String?
Reads one cookie by name.
readAll() Map<String, String>
Reads all currently visible cookies.
remove(String name, {String path = '/', String? domain, bool secure = false, CookieSameSite? sameSite}) → void
Removes a cookie by writing an expired value for name.
toString() String
A string representation of this object.
inherited
write(String name, String value, {DateTime? expires, Duration? maxAge, String path = '/', String? domain, bool secure = false, CookieSameSite? sameSite}) → void
Writes a browser cookie with common security and lifetime options.

Operators

operator ==(Object other) bool
The equality operator.
inherited