Cursor class

CSS cursor value.

Constructors

Cursor(String value)
Creates a cursor value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS cursor string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS cursor string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

auto → const Cursor
defaultCursor → const Cursor
grab → const Cursor
grabbing → const Cursor
help → const Cursor
move → const Cursor
notAllowed → const Cursor
pointer → const Cursor
progress → const Cursor
text → const Cursor
wait → const Cursor