DescriptionItem class

Label/value item rendered by DescriptionList.

Constructors

DescriptionItem({required String label, required Object value})
Creates a description list item.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
Term or field name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value Object
Description content for label.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited