Display enum

CSS display values.

Inheritance
Available extensions

Values

block → const Display

CSS block.

const Display('block')
inline → const Display

CSS inline.

const Display('inline')
inlineBlock → const Display

CSS inline-block.

const Display('inline-block')
flex → const Display

CSS flex.

const Display('flex')
inlineFlex → const Display

CSS inline-flex.

const Display('inline-flex')
grid → const Display

CSS grid.

const Display('grid')
none → const Display

CSS none.

const Display('none')

Properties

css String
CSS keyword emitted for this value.
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Display>
A constant List of the values in this enum, in order of their declaration.