Flex class

Typed CSS flex shorthand value.

Constructors

Flex(Object grow, Object shrink, Object basis)
Creates a custom flex shorthand value.
const
Flex.auto()
Creates 1 1 auto.
const
Flex.fill()
Creates 1 1 auto.
const
Flex.grow([Object grow = 1])
Creates 1 1 0% by default.
const
Flex.none()
Creates 0 0 auto.
const

Properties

basis Object
CSS flex-basis component.
final
grow Object
CSS flex-grow component.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shrink Object
CSS flex-shrink component.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() String
Converts this shorthand to a CSS flex value.
toString() String
Returns the CSS flex value.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited