FlexWrap class

CSS flex-wrap value.

Constructors

FlexWrap(String value)
Creates a flex-wrap value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS flex-wrap string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS flex-wrap string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

nowrap → const FlexWrap
wrap → const FlexWrap
wrapReverse → const FlexWrap