FlintNode class abstract

Base type for all renderable Flint UI nodes.

Prefer returning View in Component build methods instead of FlintNode to support returning raw text, lists, or other components.

Constructors

FlintNode()
Creates a Flint UI node.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited