FlintPageContext class

Context passed through page middleware before rendering.

Constructors

FlintPageContext({required Element host, required FlintPage page})
Creates middleware context for a page render.

Properties

hashCode int
The hash code for this object.
no setterinherited
host → Element
Host element that will receive the rendered page.
final
page FlintPage
Page payload read from the host element.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stopped bool
Whether middleware has stopped page rendering.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
stop() → void
Stops page rendering after the current middleware returns.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited