FlintRawHtml class

Raw HTML node used by server rendering for trusted HTML fragments.

Inheritance

Constructors

FlintRawHtml(String value, {bool trusted = true})
Creates a raw HTML node.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trusted bool
Whether value should be rendered as HTML instead of text.
final
value String
HTML content to render without escaping when trusted.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited