FlintSelectedFile class

A browser file selected from a Flint UI file input.

Constructors

FlintSelectedFile({required String name, required String mimeType, required int size, required String dataUrl, required String base64})
const

Properties

base64 String
final
dataUrl String
final
hashCode int
The hash code for this object.
no setterinherited
isImage bool
no setter
isVideo bool
no setter
mimeType String
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited