FlintStateUpdater typedef
FlintStateUpdater =
void Function()
Callback used to mutate component state before a rerender is scheduled.
Implementation
typedef FlintStateUpdater = void Function();
Callback used to mutate component state before a rerender is scheduled.
typedef FlintStateUpdater = void Function();