FontFamily class

CSS font-family value.

Constructors

FontFamily(String value)
Creates a font family from a raw CSS value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS font-family string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS font-family string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

systemSans → const FontFamily
System sans-serif font stack.