FunctionalComponent class

Component wrapper for a function that returns a FlintNode.

Inheritance

Constructors

FunctionalComponent(FlintNode builder())
Creates a component backed by builder.

Properties

builder FlintNode Function()
Builds the node tree for this functional component.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach(void scheduleRender()) → void
Attaches the render scheduler used by setState.
inherited
build() FlintNode
Builds this component by calling builder.
override
didMount() → void
Called after the component is first mounted in the browser.
inherited
didUpdate() → void
Called after the component updates following a rerender.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setState(FlintStateUpdater update) → void
Applies update and schedules this component to render again.
inherited
toString() String
A string representation of this object.
inherited
willUnmount() → void
Called before the component is removed from the tree.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited