GeoCoordinates class
Position coordinates returned by browser geolocation.
Coordinates use the browser Geolocation API values. Latitude and longitude are decimal degrees; accuracy values are meters.
Constructors
Properties
- accuracy → double
-
Estimated horizontal accuracy in meters.
final
- altitude → double?
-
Altitude in meters, when provided by the browser.
final
- altitudeAccuracy → double?
-
Estimated altitude accuracy in meters, when provided by the browser.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- heading → double?
-
Travel direction in degrees, when provided by the browser.
final
- latitude → double
-
Latitude in decimal degrees.
final
- longitude → double
-
Longitude in decimal degrees.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double?
-
Travel speed in meters per second, when provided by the browser.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited