GeoWatch class

Active geolocation watch handle.

Pass this value to GeoLocationController.clearWatch to stop live location updates.

Constructors

GeoWatch(int id)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
id int
Browser watch identifier.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited