Gradient class

CSS gradient value for typed backgrounds.

Constructors

Gradient(String value)
Creates a gradient from a raw CSS value.
const
Gradient.linear(num angle, List<Object> stops)
Creates a linear-gradient(...) from angle and color stops.
factory
Gradient.linearColors(num angle, List<Object> colors)
Creates an evenly distributed linear gradient from colors.
factory
Gradient.radial(String shape, List<Object> stops)
Creates a radial-gradient(...) from shape and color stops.
factory
Gradient.radialCircle({Object? at, required List<Object> stops})
Creates a circular radial gradient.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS gradient string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS gradient string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited