GradientPosition class

Position value used by radial gradients.

Constructors

GradientPosition(String value)
Creates a gradient position from a raw CSS value.
const
GradientPosition.percent(num x, num y)
Creates a percentage-based gradient position.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS position string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS position string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

bottomLeft → const GradientPosition
Bottom-left gradient position.
bottomRight → const GradientPosition
Bottom-right gradient position.
center → const GradientPosition
Center gradient position.
topLeft → const GradientPosition
Top-left gradient position.
topRight → const GradientPosition
Top-right gradient position.