GradientStop class

Color stop used in typed gradient factories.

Constructors

GradientStop(Object color, [Object? position])
Creates a gradient stop from a color and optional position.
const

Properties

color Object
Stop color.
final
hashCode int
The hash code for this object.
no setterinherited
position Object?
Optional stop position.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() String
Converts this stop to a CSS gradient stop.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited