Gradients class

Built-in gradients for Flint UI examples and components.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

ocean → const Gradient
Blue ocean linear gradient.
sky → const Gradient
Blue-to-sky linear gradient.
softPanel → const Gradient
Layered soft panel background gradient.