GridTemplateColumns class

CSS grid-template-columns value with helpers for common layouts.

Constructors

GridTemplateColumns(String value)
Creates a grid template from raw CSS.
const
GridTemplateColumns.autoFill(Object minWidth, {Object max = GridTrack.oneFr})
Creates a responsive auto-fill grid.
factory
GridTemplateColumns.autoFit(Object minWidth, {Object max = GridTrack.oneFr})
Creates a responsive auto-fit grid.
factory
GridTemplateColumns.repeat(Object count, Object track)
Creates a repeat(...) grid template.
factory
GridTemplateColumns.repeatTracks(Object count, List<Object> tracks)
Creates a repeated multi-track grid template.
factory
GridTemplateColumns.tracks(List<Object> tracks)
Creates grid columns from a list of tracks.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS grid-template-columns string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS grid-template-columns string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fluid GridTemplateColumns
CSS minmax(0, 1fr).
final

Constants

one → const GridTemplateColumns
CSS 1fr.