GridTrack class

CSS grid track value used by grid template helpers.

Constructors

GridTrack(String value)
Creates a grid track from raw CSS.
const
GridTrack.fitContent(Object value)
Creates a fit-content(...) grid track.
factory
GridTrack.fr(num value)
Creates a fractional grid track.
const
GridTrack.minmax(Object min, Object max)
Creates a minmax(...) grid track.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS grid track string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS grid track string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

fluid GridTrack
CSS minmax(0, 1fr) grid track.
final

Constants

auto → const GridTrack
CSS auto grid track.
maxContent → const GridTrack
CSS max-content grid track.
minContent → const GridTrack
CSS min-content grid track.
oneFr → const GridTrack
CSS 1fr grid track.