HeadTag class

Describes a browser <head> tag managed by Flint UI.

Constructors

HeadTag(String tag, {Map<String, Object?> props = const {}, String? content})
Creates a head tag descriptor.
const

Properties

content String?
Optional text content for tags such as script and style.
final
hashCode int
The hash code for this object.
no setterinherited
key String
Stable key used to update or replace matching head elements.
no setter
props Map<String, Object?>
Attributes applied to the head element.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
Tag name, such as meta, link, script, or style.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited