IconData class

A reusable SVG icon definition for Flint UI.

Constructors

IconData(String name, {String viewBox = '0 0 24 24', required List<IconShape> shapes})
Creates an icon definition.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String
Stable icon name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shapes List<IconShape>
SVG child shapes that draw this icon.
final
viewBox String
SVG view box used by this icon.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited