IconShape class

A low-level SVG shape used by IconData.

Constructors

IconShape(String tag, Map<String, Object?> props)
Creates a shape with tag and props.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
props Map<String, Object?>
SVG attributes for the shape.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
SVG tag name, such as path, circle, or line.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNode() FlintElement
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited