ImageLoading enum
Browser image loading strategy.
Values
- eager → const ImageLoading
-
Load the image immediately.
const ImageLoading('eager') - lazy → const ImageLoading
-
Defer loading until the image is near the viewport.
const ImageLoading('lazy')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
HTML
loadingattribute value.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ImageLoading> - A constant List of the values in this enum, in order of their declaration.