Link class
Anchor element with optional button-style variants.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- Link
Constructors
-
Link({required String href, Object? child, List<
Object?> children = const [], String? target, String? rel, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle, ButtonVariant? variant, Tone tone = Tone.primary, ComponentSize size = ComponentSize.md, bool disabled = false}) -
Creates a link to
hrefwith optional content and styles.
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited