isAttached property
bool
get
isAttached
Whether this controller is currently attached to a browser media element.
Implementation
bool get isAttached => false;
Whether this controller is currently attached to a browser media element.
bool get isAttached => false;