MediaPreload enum

Browser media preload strategy for audio and video elements.

Inheritance
Available extensions

Values

auto → const MediaPreload

Let the browser choose how much media to preload.

const MediaPreload('auto')
metadata → const MediaPreload

Load only metadata such as duration and dimensions.

const MediaPreload('metadata')
none → const MediaPreload

Do not preload media until the user starts playback.

const MediaPreload('none')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
HTML preload attribute value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MediaPreload>
A constant List of the values in this enum, in order of their declaration.