muted property
Whether the preview starts muted.
Camera previews usually need this to avoid local audio feedback.
Implementation
final bool muted;
Whether the preview starts muted.
Camera previews usually need this to avoid local audio feedback.
final bool muted;