MediaRecorderController class
Server-safe recording controller.
Constructors
- MediaRecorderController()
- Creates a media recorder controller.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPaused → bool
-
Whether an active recording is paused.
no setter
- isRecording → bool
-
Whether a recording is active.
no setter
- isSupported → bool
-
Whether MediaRecorder is available in this runtime.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
pause(
) → void - Pauses recording.
-
requestData(
) → void - Requests the current data chunk from the browser recorder.
-
resume(
) → void - Resumes recording.
-
start(
Object? stream, {CapturedMediaKind kind = CapturedMediaKind.video, MediaRecordingOptions options = const MediaRecordingOptions()}) → Future< void> - Starts recording a browser media stream.
-
stop(
) → Future< CapturedMedia> - Stops recording and returns captured media.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited