MediaRecordingOptions class
Options for browser media recording.
Constructors
Properties
- audioBitsPerSecond → int?
-
Requested audio bit rate.
final
- bitsPerSecond → int?
-
Requested combined bit rate.
final
- filename → String?
-
Suggested output filename.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String?
-
Requested recording MIME type.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timeslice → Duration?
-
Optional chunk interval for
dataavailableevents.final - videoBitsPerSecond → int?
-
Requested video bit rate.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited