Modal class
Modal dialog overlay with optional header, close action, and footer actions.
- Inheritance
Constructors
-
Modal({required bool open, String? title, Object? child, List<
Object?> children = const [], Object? actions, String size = 'md', String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle, void onClose(Object event)?, bool closeOnBackdrop = true}) -
Creates a modal dialog controlled by
open.
Properties
- actions → Object?
-
final
- child → Object?
-
final
-
children
→ List<
Object?> -
final
- className → String?
-
final
- closeOnBackdrop → bool
-
final
- dartStyle → DartStyle?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onClose → void Function(Object event)?
-
final
- open → bool
-
final
- preserveState → bool
-
Whether Flint should preserve this component instance across parent
rerenders when the runtime type and tree position match.
no setterinherited
-
props
→ Map<
String, Object?> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → String
-
final
-
style
→ Map<
String, Object?> -
final
- title → String?
-
final
Methods
-
attach(
void scheduleRender()) → void -
Attaches the render scheduler used by setState.
inherited
-
build(
) → Object? -
Builds this component's renderable output.
override
-
didMount(
) → void -
Called after the component is first mounted in the browser.
inherited
-
didUpdate(
) → void -
Called after the component updates following a rerender.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setState(
FlintStateUpdater update) → void -
Applies
updateand schedules this component to render again.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateFrom(
covariant FlintComponent next) → void -
Receives the next component instance when Flint preserves this instance.
inherited
-
willUnmount(
) → void -
Called before the component is removed from the tree.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited