ObjectFit class

CSS object-fit value.

Constructors

ObjectFit(String value)
Creates an object-fit value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS object-fit string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS object-fit string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

contain → const ObjectFit
cover → const ObjectFit
fill → const ObjectFit
none → const ObjectFit
scaleDown → const ObjectFit