Overflow class

CSS overflow value.

Constructors

Overflow(String value)
Creates an overflow value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS overflow string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS overflow string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

auto → const Overflow
clip → const Overflow
hidden → const Overflow
scroll → const Overflow
visible → const Overflow