PhotoCaptureController class

Server-safe photo capture controller.

Constructors

PhotoCaptureController()
Creates a photo capture controller.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
isSupported bool
Whether photo capture is available in this runtime.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
takePhotoFromElement(String elementId, {String mimeType = 'image/png', double? quality, String? filename}) Future<CapturedMedia>
Captures a still image from a rendered video element.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited