QueryParams constructor
const
QueryParams()
Creates a query parameter helper for the current browser URL.
Implementation
const QueryParams();
Creates a query parameter helper for the current browser URL.
const QueryParams();