Resize class

CSS resize value.

Constructors

Resize(String value)
Creates a resize value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS resize string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS resize string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

block → const Resize
both → const Resize
horizontal → const Resize
inline → const Resize
none → const Resize
vertical → const Resize