ResourceStatus enum

Lifecycle state for an API-backed resource.

Inheritance
Available extensions

Values

idle → const ResourceStatus

The resource has not been loaded yet.

loading → const ResourceStatus

A request is currently in flight.

success → const ResourceStatus

Data was loaded successfully.

error → const ResourceStatus

The most recent request failed.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ResourceStatus>
A constant List of the values in this enum, in order of their declaration.