RichTextToolbarItem enum

Semantic toolbar actions supported by the rich text editor.

Inheritance
Available extensions

Values

bold → const RichTextToolbarItem

Toggle bold formatting on selection.

italic → const RichTextToolbarItem

Toggle italic formatting on selection.

underline → const RichTextToolbarItem

Toggle underline formatting on selection.

strikeThrough → const RichTextToolbarItem

Toggle strikethrough formatting on selection.

heading1 → const RichTextToolbarItem

Formats the block as a level 1 heading.

heading2 → const RichTextToolbarItem

Formats the block as a level 2 heading.

paragraph → const RichTextToolbarItem

Formats the block as a paragraph.

bulletList → const RichTextToolbarItem

Inserts a bulleted list.

orderedList → const RichTextToolbarItem

Inserts a numbered list.

blockquote → const RichTextToolbarItem

Formats the block as a blockquote.

codeBlock → const RichTextToolbarItem

Formats the block as a preformatted code block.

Inserts/modifies a hyperlink.

image → const RichTextToolbarItem

Inserts an image.

removeFormat → const RichTextToolbarItem

Removes all formatting from selection.

divider → const RichTextToolbarItem

Renders a vertical line separating toolbar groups.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<RichTextToolbarItem>
A constant List of the values in this enum, in order of their declaration.