ScrollBehavior class

CSS scroll-behavior value.

Constructors

ScrollBehavior(String value)
Creates a scroll behavior value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS scroll-behavior string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS scroll-behavior string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

auto → const ScrollBehavior
CSS auto.
smooth → const ScrollBehavior
CSS smooth.