ScrollbarDisplay class

CSS scrollbar visibility helper.

Constructors

ScrollbarDisplay(String value)
Creates a scrollbar display value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Scrollbar visibility keyword.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS scrollbar display string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

auto → const ScrollbarDisplay
none → const ScrollbarDisplay