Shadow class

Typed CSS box-shadow value.

Constructors

Shadow({Object x = 0, Object y = 1, Object blur = 2, Object spread = 0, required Object color, bool inset = false})
Creates a box shadow value.
const

Properties

blur Object
Shadow blur radius.
final
color Object
Shadow color.
final
hashCode int
The hash code for this object.
no setterinherited
inset bool
Whether the shadow is inset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
spread Object
Shadow spread radius.
final
x Object
Horizontal shadow offset.
final
y Object
Vertical shadow offset.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() String
Converts this shadow to a CSS box-shadow value.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited