SizeValue class

CSS size value with an explicit unit.

Constructors

SizeValue(String value)
Creates a size from a raw CSS value.
const
SizeValue.em(num value)
Creates an em size.
const
SizeValue.percent(num value)
Creates a percentage size.
const
SizeValue.px(num value)
Creates a pixel size.
const
SizeValue.rem(num value)
Creates a rem size.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS size string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS size string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

auto → const SizeValue
CSS auto size.
full → const SizeValue
CSS 100% size.