didMount method
Called after the component is first mounted in the browser.
Implementation
@override
void didMount() {
super.didMount();
_startTimer();
}
Called after the component is first mounted in the browser.
@override
void didMount() {
super.didMount();
_startTimer();
}