willUnmount method
Called before the component is removed from the tree.
Implementation
@override
void willUnmount() {
_timer?.cancel();
super.willUnmount();
}
Called before the component is removed from the tree.
@override
void willUnmount() {
_timer?.cancel();
super.willUnmount();
}