StyleFilter class

Typed CSS filter value.

Constructors

StyleFilter(String value)
Creates a filter from a raw CSS value.
const
StyleFilter.blur(Object value)
Creates a blur(...) filter.
factory
StyleFilter.brightness(num percent)
Creates a brightness(...) filter.
factory
StyleFilter.combine(List<StyleFilter> filters)
Combines multiple filters into one CSS filter value.
factory
StyleFilter.contrast(num percent)
Creates a contrast(...) filter.
factory
StyleFilter.saturate(num percent)
Creates a saturate(...) filter.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS filter string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS filter string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited