StyleRule class

CSS rule with base styles and common interaction state styles.

Constructors

StyleRule(Map<String, Object?> styles, {Map<String, Object?> hover = const {}, Map<String, Object?> focus = const {}, Map<String, Object?> focusVisible = const {}, Map<String, Object?> active = const {}, Map<String, Object?> disabled = const {}, Map<String, Object?> checked = const {}, Map<String, Object?> selected = const {}, Map<String, Object?> expanded = const {}, Map<String, Object?> invalid = const {}})
Creates a style rule with optional interaction state declarations.
const
StyleRule.nested(Map<String, Map<String, Object?>> nestedRules)
Creates a nested style rule for an at-rule.
const

Properties

active Map<String, Object?>
CSS declarations for :active.
final
checked Map<String, Object?>
CSS declarations for :checked.
final
disabled Map<String, Object?>
CSS declarations for :disabled.
final
expanded Map<String, Object?>
CSS declarations for [aria-expanded="true"].
final
focus Map<String, Object?>
CSS declarations for :focus.
final
focusVisible Map<String, Object?>
CSS declarations for :focus-visible.
final
hashCode int
The hash code for this object.
no setterinherited
hover Map<String, Object?>
CSS declarations for :hover.
final
invalid Map<String, Object?>
CSS declarations for [aria-invalid="true"].
final
nestedRules Map<String, Map<String, Object?>>
Nested rules used inside at-rules such as media queries.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected Map<String, Object?>
CSS declarations for [aria-selected="true"].
final
styles Map<String, Object?>
Base CSS declarations.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited