StyleTransform class

Typed CSS transform value.

Constructors

StyleTransform(String value)
Creates a transform from a raw CSS value.
const
StyleTransform.combine(List<StyleTransform> transforms)
Combines multiple transforms into one CSS transform value.
factory
StyleTransform.rotate(Object value)
Creates a rotate(...) transform.
factory
StyleTransform.scale(num value)
Creates a scale(...) transform.
factory
StyleTransform.translate({Object x = 0, Object y = 0})
Creates a translate(...) transform.
factory
StyleTransform.translateX(Object value)
Creates a translateX(...) transform.
factory
StyleTransform.translateY(Object value)
Creates a translateY(...) transform.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS transform string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS transform string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited