TabItem class
Tab option rendered by Tabs.
Constructors
Properties
- disabled → bool
-
Whether this tab should be unavailable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → Object?
-
Optional leading icon or element.
final
- key → String
-
Stable key used to identify the tab.
final
- label → String
-
Visible tab label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited