Table class
Scrollable data table with loading, empty, and selectable row states.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- Table
Constructors
-
Table({List<
TableColumn> columns = const [], List<TableRowData> rows = const [], Object? emptyState, bool loading = false, Object? loadingState, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle, String? tableClassName, Map<String, Object?> tableProps = const {}, Map<String, Object?> tableStyle = const {}, DartStyle? tableDartStyle, String? headerClassName, Map<String, Object?> headerStyle = const {}, DartStyle? headerDartStyle, String? rowClassName, String? selectedRowClassName, Map<String, Object?> rowStyle = const {}, Map<String, Object?> selectedRowStyle = const {}, DartStyle? rowDartStyle, DartStyle? selectedRowDartStyle, String? cellClassName, Map<String, Object?> cellStyle = const {}, DartStyle? cellDartStyle, void onRowClick(Object event, TableRowData row)?}) -
Creates a table from
columnsandrows.
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited