TableColumn class

Column definition used by Table.

Constructors

TableColumn({required String key, required String label, Object? header, String? align, String? className, Map<String, Object?> headerStyle = const {}, Map<String, Object?> cellStyle = const {}, DartStyle? headerDartStyle, DartStyle? cellDartStyle})
Creates a table column definition.
const

Properties

align String?
CSS text alignment for header and body cells.
final
cellDartStyle DartStyle?
Additional typed styles for this column's body cells.
final
cellStyle Map<String, Object?>
Additional inline styles for this column's body cells.
final
className String?
Additional CSS class for this column's cells.
final
hashCode int
The hash code for this object.
no setterinherited
Optional custom header content.
final
headerDartStyle DartStyle?
Additional typed styles for this column's header cell.
final
headerStyle Map<String, Object?>
Additional inline styles for this column's header cell.
final
key String
Key used to read each row cell value.
final
label String
Fallback text rendered in the column header.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited