TableRowData class

Row data rendered by Table.

Constructors

TableRowData({String? key, required Map<String, Object?> cells, Object? actions, bool selected = false, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle})
Creates table row data.
const

Properties

actions Object?
Optional action content rendered at the end of the row.
final
cells Map<String, Object?>
Cell content keyed by TableColumn.key.
final
className String?
Additional CSS class for this row.
final
dartStyle DartStyle?
Additional typed styles for this row.
final
hashCode int
The hash code for this object.
no setterinherited
key String?
Optional stable row key emitted as data-row-key.
final
props Map<String, Object?>
Additional element props for this row.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selected bool
Whether this row should render as selected.
final
style Map<String, Object?>
Additional inline styles for this row.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited