Tabs class

Tablist control for switching between keyed tabs.

Inheritance

Constructors

Tabs({List<TabItem> tabs = const [], String? activeKey, NavVariant variant = NavVariant.underline, Tone tone = Tone.primary, ComponentSize size = ComponentSize.md, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle, void onChanged(Object event, TabItem tab)?})
Creates a tablist from tabs.

Properties

children List<FlintNode>
Child nodes rendered inside the element.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props Map<String, Object?>
Element attributes, event handlers, classes, and styles.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
HTML tag name for this element.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited