Text class

Text node and semantic text element helpers.

Inheritance

Constructors

Text(Object? value)
Creates a plain text node from value.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
Text content for this node.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

h1(Object? value, {String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) FlintElement
Creates an h1 text element.
h2(Object? value, {String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) FlintElement
Creates an h2 text element.
h3(Object? value, {String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) FlintElement
Creates an h3 text element.
p(Object? value, {String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) FlintElement
Creates a paragraph text element.
small(Object? value, {String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) FlintElement
Creates a small text element.
span(Object? value, {String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) FlintElement
Creates an inline span text element.
strong(Object? value, {String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) FlintElement
Creates a strong text element.