TextDecorationStyle class

CSS text-decoration value.

Constructors

TextDecorationStyle(String value)
Creates a text-decoration value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS text-decoration string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS text-decoration string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

none → const TextDecorationStyle
underline → const TextDecorationStyle