TextField class

Text input field with label, help text, validation, and controller support.

Inheritance

Constructors

TextField({String? label, String? name, TextEditingController? controller, Object? value, String? placeholder, String type = 'text', bool required = false, bool disabled = false, InputVariant variant = InputVariant.outline, ComponentSize size = ComponentSize.md, String? error, FormErrors? errors, String? helpText, String? className, Map<String, Object?> props = const {}, Map<String, Object?> inputProps = const {}, Map<String, Object?> style = const {}, Map<String, Object?> inputStyle = const {}, DartStyle? dartStyle, DartStyle? inputDartStyle, void onChanged(Object event)?})
Creates a text input field.

Properties

children List<FlintNode>
Child nodes rendered inside the element.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props Map<String, Object?>
Element attributes, event handlers, classes, and styles.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
HTML tag name for this element.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited