TextOverflow class

CSS text-overflow value.

Constructors

TextOverflow(String value)
Creates a text-overflow value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS text-overflow string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS text-overflow string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

clip → const TextOverflow
ellipsis → const TextOverflow