TextTransform class

CSS text-transform value.

Constructors

TextTransform(String value)
Creates a text-transform value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS text-transform string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS text-transform string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

capitalize → const TextTransform
lowercase → const TextTransform
none → const TextTransform
uppercase → const TextTransform