ThemeTokens class

Collection of design token values that compile to CSS variables.

Constructors

ThemeTokens(Map<String, Object?> values)
Creates a token collection from values.
const

Properties

cssVariables Map<String, Object?>
CSS custom properties generated from token values.
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, Object?>
Token values keyed by logical token name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(String name) Object?
Resolves a token by name.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited