TimelineItem class

Event entry rendered by Timeline.

Constructors

TimelineItem({required String title, String? description, String? time, Tone tone = Tone.neutral})
Creates a timeline event item.
const

Properties

description String?
Optional event description.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
time String?
Optional event time or timestamp label.
final
title String
Primary event title.
final
tone Tone
Tone used for the event marker.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited