ToastService class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
error(String title, {String? message, Duration duration = const Duration(seconds: 5), ToastPlacement placement = ToastPlacement.topRight})
→ void
-
-
info(String title, {String? message, Duration duration = const Duration(seconds: 3), ToastPlacement placement = ToastPlacement.topRight})
→ void
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
success(String title, {String? message, Duration duration = const Duration(seconds: 3), ToastPlacement placement = ToastPlacement.topRight})
→ void
-
-
toString()
→ String
-
A string representation of this object.
inherited
-
warning(String title, {String? message, Duration duration = const Duration(seconds: 4), ToastPlacement placement = ToastPlacement.topRight})
→ void
-