TokenRef class

Reference to a design token CSS variable.

Constructors

TokenRef(String name, {Object? fallback})
Creates a token reference.
const

Properties

fallback Object?
Optional fallback value used when the CSS variable is missing.
final
hashCode int
The hash code for this object.
no setterinherited
name String
Logical token name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() String
Converts this reference to a CSS var(...) expression.
toString() String
Returns the CSS variable reference.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited