Tone enum
Semantic tone used by shared widget theme helpers.
Values
- neutral → const Tone
-
Neutral tone for default UI surfaces and actions.
- primary → const Tone
-
Primary brand/action tone.
- success → const Tone
-
Success or positive status tone.
- warning → const Tone
-
Warning or caution status tone.
- danger → const Tone
-
Danger or destructive status tone.
- info → const Tone
-
Informational status tone.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited