WhiteSpace class

CSS white-space value.

Constructors

WhiteSpace(String value)
Creates a white-space value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS white-space string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS white-space string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

breakSpaces → const WhiteSpace
normal → const WhiteSpace
nowrap → const WhiteSpace
pre → const WhiteSpace
preLine → const WhiteSpace
preWrap → const WhiteSpace