WillChange class

CSS will-change value.

Constructors

WillChange(String value)
Creates a will-change value.
const
WillChange.properties(List<Object> properties)
Creates a comma-separated list of properties expected to change.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS will-change string.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS will-change string.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

auto → const WillChange
contents → const WillChange
opacity → const WillChange
scrollPosition → const WillChange
transform → const WillChange