createRootForElement function
Creates a root renderer for an existing browser element.
Implementation
FlintRoot createRootForElement(web.Element element) => FlintRoot(element);
Creates a root renderer for an existing browser element.
FlintRoot createRootForElement(web.Element element) => FlintRoot(element);