navigate function
void
navigate(
Pushes a new browser history entry without reloading the page.
Implementation
void navigate(String url, {Object? state}) {
navigation.navigate(url, state: state);
}
Pushes a new browser history entry without reloading the page.
void navigate(String url, {Object? state}) {
navigation.navigate(url, state: state);
}