currentPath top-level property
String
get
currentPath
The current browser path without query string or hash.
Implementation
String get currentPath => navigation.currentPath;
The current browser path without query string or hash.
String get currentPath => navigation.currentPath;