currentQuery top-level property
String
get
currentQuery
The current browser query string, including the leading ?.
Implementation
String get currentQuery => navigation.currentQuery;
The current browser query string, including the leading ?.
String get currentQuery => navigation.currentQuery;