MailConfig class

Constructors

MailConfig()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

load() → void
Load mail configuration from .env. Call this once during app bootstrap or anywhere you need to reconfigure. Safe to call from an isolate before sending queued mail.