BarChartSeries class

Represents a single data series in a BarChart.

Constructors

BarChartSeries({required List<double> data, String barColor = '#6366f1', String label = ''})
const

Properties

barColor String
final
data List<double>
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited