cancelHistoryBatch method
void
cancelHistoryBatch()
Cancels an active history batch without adding an undo entry.
Implementation
void cancelHistoryBatch() {
_historyBatchDepth = 0;
_historyBatchSnapshot = null;
}
Cancels an active history batch without adding an undo entry.
void cancelHistoryBatch() {
_historyBatchDepth = 0;
_historyBatchSnapshot = null;
}