hasScopedStyles property
bool
get
hasScopedStyles
Whether this style contains any responsive or state overrides.
Implementation
bool get hasScopedStyles => hasBreakpoints || hasStateStyles;
Whether this style contains any responsive or state overrides.
bool get hasScopedStyles => hasBreakpoints || hasStateStyles;