DocReadingMode enum

Visual reading theme for rendered documents.

Inheritance
Available extensions

Values

paper → const DocReadingMode

Authentic white paper mode (exact document styling).

dark → const DocReadingMode

Dark canvas mode with high-contrast text for night reading.

sepia → const DocReadingMode

Warm sepia tone for reduced eye strain.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<DocReadingMode>
A constant List of the values in this enum, in order of their declaration.