DocTocItem class

Represents an entry in a document's Table of Contents (Outline).

Constructors

DocTocItem({required String title, int pageNumber = 1, Object? dest, List<DocTocItem> children = const []})

Properties

children List<DocTocItem>
Subsections / nested headings.
final
dest Object?
Raw destination object or anchor.
final
hashCode int
The hash code for this object.
no setterinherited
pageNumber int
Target 1-based page number.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
The section / heading title.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited