DocxViewer class

Native Word document viewer stub for non-web / server rendering.

Inheritance

Constructors

DocxViewer({required String src, String? title, DocViewerController? controller, bool showToolbar = true, String? className, DartStyle? dartStyle, FlintNode? fallback, FlintNode? loadingWidget})

Properties

className String?
final
controller DocViewerController?
final
dartStyle DartStyle?
final
fallback FlintNode?
final
hashCode int
The hash code for this object.
no setterinherited
loadingWidget FlintNode?
final
preserveState bool
Whether Flint should preserve this component instance across parent rerenders when the runtime type and tree position match.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showToolbar bool
final
src String
final
title String?
final

Methods

attach(void scheduleRender()) → void
Attaches the render scheduler used by setState.
inherited
build() View?
Builds this component's renderable output.
override
didMount() → void
Called after the component is first mounted in the browser.
inherited
didUpdate() → void
Called after the component updates following a rerender.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setState(FlintStateUpdater update, {bool render = true}) → void
Applies update and schedules this component to render again.
inherited
shouldUpdate(covariant FlintComponent next) bool
Whether this component should rerender when it is updated from a new instance in the parent tree.
inherited
toString() String
A string representation of this object.
inherited
updateFrom(covariant FlintComponent next) → void
Receives the next component instance when Flint preserves this instance.
inherited
willUnmount() → void
Called before the component is removed from the tree.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited