shouldUpdate method

bool shouldUpdate(
  1. covariant FlintComponent next
)

Whether this component should rerender when it is updated from a new instance in the parent tree.

Defaults to true. Override this to return false to prevent the component from clearing and rebuilding its DOM nodes during parent rerenders.

Implementation

bool shouldUpdate(covariant FlintComponent next) => true;