LineChartSeries class

Represents a single data series in a LineChart.

Constructors

LineChartSeries({required List<double> data, String strokeColor = '#6366f1', String fillColor = 'rgba(99, 102, 241, 0.08)', double strokeWidth = 2.5, String label = ''})
const

Properties

data List<double>
final
fillColor String
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strokeColor String
final
strokeWidth double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited