Rem class

Convenient rem size value.

Inheritance

Constructors

Rem(num value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
CSS size string.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
Returns the CSS size string.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited