ScaleIn class

ScaleIn smoothly scales content from 0.95 to 1 on mount.

Inheritance

Constructors

ScaleIn({Object? child, List<Object?> children = const [], Duration duration = const Duration(milliseconds: 300), Duration delay = Duration.zero, String curve = 'cubic-bezier(0.16, 1, 0.3, 1)', String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle})
Creates a scale-in animation widget.

Properties

children List<FlintNode>
Child nodes rendered inside the element.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
props Map<String, Object?>
Element attributes, event handlers, classes, and styles.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tag String
HTML tag name for this element.
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited