TerminalConnectionState enum

Connection lifecycle states reported by Terminal.

Inheritance
Available extensions

Values

idle → const TerminalConnectionState

No connection has been requested yet.

connecting → const TerminalConnectionState

A WebSocket connection is being established.

connected → const TerminalConnectionState

Input and output can flow through the WebSocket.

reconnecting → const TerminalConnectionState

The terminal is waiting to retry a dropped connection.

error → const TerminalConnectionState

The most recent connection attempt failed.

closed → const TerminalConnectionState

The connection was closed or explicitly disconnected.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TerminalConnectionState>
A constant List of the values in this enum, in order of their declaration.