isAttached property
bool
get
isAttached
Whether this controller is currently attached to a browser terminal.
Implementation
bool get isAttached => _owner != null;
Whether this controller is currently attached to a browser terminal.
bool get isAttached => _owner != null;