TerminalTheme class

Light and dark colors used by the xterm.js renderer.

Constructors

TerminalTheme({String lightBackground = '#ffffff', String lightForeground = '#0f172a', String lightCursor = '#0284c7', String lightSelection = 'rgba(2, 132, 199, 0.22)', String darkBackground = '#020617', String darkForeground = '#f8fafc', String darkCursor = '#38bdf8', String darkSelection = 'rgba(56, 189, 248, 0.28)'})
Creates a terminal color palette.
const

Properties

darkBackground String
Terminal background in dark mode.
final
darkCursor String
Terminal cursor in dark mode.
final
darkForeground String
Terminal foreground in dark mode.
final
darkSelection String
Terminal selection in dark mode.
final
hashCode int
The hash code for this object.
no setterinherited
lightBackground String
Terminal background in light mode.
final
lightCursor String
Terminal cursor in light mode.
final
lightForeground String
Terminal foreground in light mode.
final
lightSelection String
Terminal selection in light mode.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited