WsRoute class

Constructors

WsRoute(String path, Handler handler, [List<Middleware> middlewares = const []])

Properties

handler Handler
final
hashCode int
The hash code for this object.
no setterinherited
middlewares List<Middleware>
final
path String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

match(String urlPath) Map<String, String>?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited