AiAgent class abstract
Contract implemented by runnable agents.
- Implementers
Constructors
- AiAgent()
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plan(
AiRunContext context) → Future< AiPlan> - Produces an execution plan for the current run context.
-
synthesize(
AiRunContext context) → Future< Map< String, dynamic> > - Produces the final structured output after plan execution.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited