AiExecutor class abstract

Contract for executing an AI plan.

Executors are responsible for walking plan steps, applying AiToolPolicy, invoking tools, recording state, and returning AiRunResult.

Constructors

AiExecutor()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

execute({required AiAgent agent, required AiRunContext context, required AiPlan plan, required AiToolRegistry toolRegistry, required AiToolPolicy toolPolicy}) Future<AiRunResult>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited