AiPlanner class abstract
Contract for turning an agent run into a plan.
Most applications can use DefaultAiPlanner. Custom planners can add routing, policy-aware planning, human approval steps, or LLM-generated plans.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createPlan(
AiAgent agent, AiRunContext context) → Future< AiPlan> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited