AiRepository class
Bundle of stores used by the AI runtime for persistence.
- Implementers
Constructors
- AiRepository({AiRunStore? runs, AiThreadStore? threads, AiTraceStore? traces, AiArtifactStore? artifacts})
-
const
Properties
- artifacts → AiArtifactStore?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runs → AiRunStore?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- threads → AiThreadStore?
-
final
- traces → AiTraceStore?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited