enabledByDefault property
bool
get
enabledByDefault
Whether the tool is allowed by the safe default policy.
Leave this as false for destructive or externally visible actions.
Implementation
bool get enabledByDefault => false;