AiToolInvocation class

Authorization request describing a planned tool call.

Constructors

AiToolInvocation({required String name, required String runId, required Map<String, dynamic> arguments, String? userId, String? tenantId, bool enabledByDefault = false, Set<String> requiredCapabilities = const {}})
const

Properties

arguments Map<String, dynamic>
final
enabledByDefault bool
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
requiredCapabilities Set<String>
final
runId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tenantId String?
final
userId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited