AiWorkflowContext class
Execution context passed into a workflow.
Constructors
Properties
-
artifacts
→ Map<
String, dynamic> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
input
→ Map<
String, dynamic> -
final
- isBackground → bool
-
final
-
metadata
→ Map<
String, dynamic> -
final
- requestContext → Context?
-
final
- runId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tenantId → String?
-
final
- threadId → String?
-
final
- userId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited