AutoAiMemoryStore class
Default memory store used by the standalone package.
Frameworks can inject their own AiMemoryStore implementation when they want database-backed memory.
- Inheritance
-
- Object
- InMemoryAiMemoryStore
- AutoAiMemoryStore
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appendRunEvent(
String runId, Map< String, dynamic> event) → Future<void> -
inherited
-
loadRunEvents(
String runId) → Future< List< Map< >String, dynamic> > -
inherited
-
loadThreadMessages(
String threadId) → Future< List< Map< >String, dynamic> > -
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
saveThreadMessage(
String threadId, Map< String, dynamic> message) → Future<void> -
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited