AutoAiRepository class

Repository that prefers database stores and falls back to in-memory stores.

Inheritance

Constructors

AutoAiRepository()
factory

Properties

artifacts AiArtifactStore?
finalinherited
fallbackArtifacts InMemoryAiArtifactStore
final
fallbackRuns InMemoryAiRunStore
final
fallbackThreads InMemoryAiThreadStore
final
fallbackTraces InMemoryAiTraceStore
final
hashCode int
The hash code for this object.
no setterinherited
runs AiRunStore?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
threads AiThreadStore?
finalinherited
traces AiTraceStore?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited