BasicTaskAgent class
Minimal example agent that copies the incoming goal into run state.
Constructors
- BasicTaskAgent({String name = 'basic_task_agent'})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
plan(
AiRunContext context) → Future< AiPlan> -
Produces an execution plan for the current run context.
override
-
synthesize(
AiRunContext context) → Future< Map< String, dynamic> > -
Produces the final structured output after plan execution.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited