DefaultAiExecutor class
Default executor that runs plan steps sequentially.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
execute(
{required AiAgent agent, required AiRunContext context, required AiPlan plan, required AiToolRegistry toolRegistry, required AiToolPolicy toolPolicy}) → Future< AiRunResult> -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited