InMemoryAiTraceStore class
In-memory trace store for development and tests.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
appendTrace(
String runId, Map< String, dynamic> event) → Future<void> -
override
-
eventsForRun(
String runId) → List< Map< String, dynamic> > - Returns all stored events for a run.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited