CancelToken class
Token used to cancel in-flight requests.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCancelled → bool
-
True when cancel was called.
no setter
- reason → String?
-
Optional cancellation reason.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
whenCancelled
→ Future<
String?> -
Completes when the token is cancelled.
no setter
Methods
-
cancel(
[String? reason]) → void - Cancels the token. Repeated calls are ignored.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited