Default class
Constructors
- Default()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
currentDate(
) → String - Returns SQL for current date depending on driver
-
currentTime(
) → String - Returns SQL for current time depending on driver
-
currentTimestamp(
) → String - Returns SQL for current timestamp depending on driver
-
currentUser(
) → String -
e(
) → double -
emptyArray(
) → List -
emptyJson(
) → Map< String, dynamic> -
emptyString(
) → String -
now(
) → DateTime - Returns a Dart DateTime object for runtime use
-
one(
) → int -
pi(
) → double -
sessionUser(
) → String -
space(
) → String -
uuid(
) → String -
version1(
) → int -
zero(
) → int