RelationDefinition<T extends Model<T> > class
Constructors
- RelationDefinition({required String name, required RelationType type, required String foreignKey, required String ownerKey, String? pivotTable, String? foreignPivotKey})
-
const
Properties
- foreignKey → String
-
final
- foreignPivotKey → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- ownerKey → String
-
final
- pivotTable → String?
-
final
-
final
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → RelationType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited