SecurityEvent class
Constructors
- SecurityEvent({required SecurityEventType type, required String ipAddress, String? path, int? attempts, DateTime? blockedUntil, DateTime? timestamp})
Properties
- attempts → int?
-
final
- blockedUntil → DateTime?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- ipAddress → String
-
final
- path → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
final
- type → SecurityEventType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited