AlignItems enum
CSS align-items values.
Values
- start → const AlignItems
-
CSS
flex-start.const AlignItems('flex-start') - center → const AlignItems
-
CSS
center.const AlignItems('center') - end → const AlignItems
-
CSS
flex-end.const AlignItems('flex-end') - stretch → const AlignItems
-
CSS
stretch.const AlignItems('stretch') - baseline → const AlignItems
-
CSS
baseline.const AlignItems('baseline')
Properties
- css → String
-
CSS keyword emitted for this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AlignItems> - A constant List of the values in this enum, in order of their declaration.