AuthSessionSnapshot class
A read-only snapshot of the current browser auth session.
Constructors
-
AuthSessionSnapshot({required String token, required Map<
String, dynamic> user}) -
Creates a session snapshot from a token and user payload.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- role → String?
-
The user's role when the user payload contains a
rolefield.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
The stored authentication token.
final
-
user
→ Map<
String, dynamic> -
The stored user payload associated with the token.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited