Breakpoint enum
Responsive breakpoint used by scoped Dart styles.
Values
- sm → const Breakpoint
-
Small screens, starting at 640px.
const Breakpoint(640) - md → const Breakpoint
-
Medium screens, starting at 768px.
const Breakpoint(768) - lg → const Breakpoint
-
Large screens, starting at 1024px.
const Breakpoint(1024) - xl → const Breakpoint
-
Extra-large screens, starting at 1280px.
const Breakpoint(1280)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- minWidth → int
-
Minimum viewport width for this breakpoint.
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
Breakpoint> - A constant List of the values in this enum, in order of their declaration.