BrowserNavigation class
Wraps browser location and history navigation for Flint UI apps.
Constructors
-
Creates a browser navigation helper.
const
Properties
- currentHash → String
-
The current browser hash, including the leading
#.no setter - currentPath → String
-
The current browser path without query string or hash.
no setter
- currentQuery → String
-
The current browser query string, including the leading
?.no setter - currentUri → Uri
-
The current browser URL parsed as a Uri.
no setter
- currentUrl → String
-
The full current browser URL.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
assign(
String url) → void -
Loads
urlthroughwindow.location.assign. -
back(
) → void - Moves one entry back in browser history.
-
forward(
) → void - Moves one entry forward in browser history.
-
go(
int delta) → void -
Moves by
deltaentries in browser history. - Pushes a new browser history entry without reloading the page.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redirect(
String url) → void -
Replaces the current page with
urlthroughwindow.location.replace. -
reload(
) → void - Reloads the current browser page.
-
replace(
String url, {Object? state}) → void - Replaces the current browser history entry without reloading the page.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited