BrowserNavigation class
Constructors
-
const
Properties
- currentHash → String
-
no setter
- currentPath → String
-
no setter
- currentQuery → String
-
no setter
- currentUri → Uri
-
no setter
- currentUrl → String
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
assign(
String url) → void -
back(
) → void -
forward(
) → void -
go(
int delta) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
redirect(
String url) → void -
reload(
) → void -
replace(
String url, {Object? state}) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited