CanvasPatternRepetition enum
Browser canvas pattern repetition options.
Values
- repeat → const CanvasPatternRepetition
-
Repeat horizontally and vertically.
const CanvasPatternRepetition('repeat') - repeatX → const CanvasPatternRepetition
-
Repeat horizontally only.
const CanvasPatternRepetition('repeat-x') - repeatY → const CanvasPatternRepetition
-
Repeat vertically only.
const CanvasPatternRepetition('repeat-y') - noRepeat → const CanvasPatternRepetition
-
Do not repeat the image.
const CanvasPatternRepetition('no-repeat')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → String
-
Browser
createPatternrepetition value.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
String? value) → CanvasPatternRepetition - Resolves a browser repetition value.
Constants
-
values
→ const List<
CanvasPatternRepetition> - A constant List of the values in this enum, in order of their declaration.