Checkbox class
Checkbox field with label, help text, and validation message support.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- Checkbox
Constructors
-
Checkbox({String? label, String? name, bool checked = false, bool disabled = false, bool indeterminate = false, String? error, FormErrors? errors, String? helpText, String? className, Map<
String, Object?> props = const {}, Map<String, Object?> inputProps = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle, void onChanged(Object event)?}) - Creates a checkbox field.
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited