EdgeInsets class

Typed spacing value for CSS margin and padding.

Constructors

EdgeInsets.all(Object value)
Creates equal edge values for every side.
const
EdgeInsets.only({Object? top, Object? right, Object? bottom, Object? left})
Creates edge values for selected sides.
const
EdgeInsets.symmetric({Object? vertical, Object? horizontal})
Creates vertical and horizontal edge values.
const

Properties

bottom Object?
Bottom edge value.
final
hashCode int
The hash code for this object.
no setterinherited
left Object?
Left edge value.
final
Right edge value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
top Object?
Top edge value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toCss() String
Converts this spacing value to a CSS shorthand.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited