EnvironmentConfig class

Constructors

EnvironmentConfig([Map<String, String> values = const {}])
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
values Map<String, String>
final

Methods

get(String key, {String? fallback}) String?
getBool(String key, {bool fallback = false}) bool
getDouble(String key, {double fallback = 0}) double
getInt(String key, {int fallback = 0}) int
merge(Map<String, String> values) EnvironmentConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited