FlintComponent class abstract
Base class for reusable Flint UI components.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
attach(
void scheduleRender()) → void - Attaches the render scheduler used by setState.
-
build(
) → FlintNode - Builds the node tree for this component.
-
didMount(
) → void - Called after the component is first mounted in the browser.
-
didUpdate(
) → void - Called after the component updates following a rerender.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setState(
FlintStateUpdater update) → void -
Applies
updateand schedules this component to render again. -
toString(
) → String -
A string representation of this object.
inherited
-
willUnmount(
) → void - Called before the component is removed from the tree.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited