FlintComponentNode class
Node wrapper that lets a FlintComponent render in the node tree.
Constructors
- FlintComponentNode(FlintComponent component)
-
Creates a node for
component.const
Properties
- component → FlintComponent
-
Component rendered by this node.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited