FlintComponentRegistry class
Registry that maps Flint page names to component builders.
- Inheritance
-
- Object
- PageRegistry
- FlintComponentRegistry
- Annotations
-
- @Deprecated('Use PageRegistry instead')
Constructors
-
FlintComponentRegistry([Map<
String, FlintPageBuilder> ? pages]) -
Creates a registry with optional initial
pages.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
pages
→ Map<
String, FlintPageBuilder> -
Registered page builders keyed by page name.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
only(
Iterable< String> names) → FlintComponentRegistry -
Returns a registry containing only the requested
names.override -
register(
String name, FlintPageBuilder builder) → void -
Registers a page
builderforname.inherited -
registerAll(
Map< String, FlintPageBuilder> pages) → void -
Registers all page builders from
pages.inherited -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
-
operator [](
String name) → FlintPageBuilder? -
Returns the page builder registered for
name.inherited