FlintElement class
DOM element node with a tag, properties, and children.
Constructors
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited