FlintEvent class
Browser event helpers exposed by Flint UI.
The VM/server stub keeps shared UI code analyzable without requiring browser DOM types.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
checked(
Object? event) → bool -
files(
Object? event) → Future< List< FlintSelectedFile> > -
firstFile(
Object? event) → Future< FlintSelectedFile?> -
html(
Object? event) → String -
isBrowserEvent(
Object? event) → bool -
preventDefault(
Object? event) → void -
stopPropagation(
Object? event) → void -
target(
Object? event) → Object? -
text(
Object? event) → String -
value(
Object? event) → String