FlintPage class

Constructors

FlintPage({required String component, Map<String, dynamic> props = const {}, String? url, String? version})
const
FlintPage.fromJson(Map<String, dynamic> json)
factory

Properties

component String
final
hashCode int
The hash code for this object.
no setterinherited
props Map<String, dynamic>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
final
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited