FlintPage class
Server-provided page payload used to mount a Flint UI page.
Constructors
Properties
- component → String
-
Registered component name to render.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, dynamic> -
Props passed from the server to the page component.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String?
-
Optional request URL associated with this page payload.
final
- version → String?
-
Optional page payload version.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited