FlintRoot class
Browser DOM root that renders Flint nodes into a host element.
Constructors
- FlintRoot(Element host)
-
Creates a root renderer for
host.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- host → Element
-
Host element that receives rendered DOM nodes.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
render(
Object? node) → void -
Renders
nodeinto the host element. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited