FlintThemeProvider class

Light and dark theme pair used by RootDesign.

Constructors

FlintThemeProvider({FlintTheme light = FlintThemes.light, FlintTheme dark = FlintThemes.dark, FlintThemeMode initialMode = FlintThemeMode.light})
Creates a provider from explicit light and dark themes.
const

Properties

dark FlintTheme
Dark theme tokens.
final
hashCode int
The hash code for this object.
no setterinherited
initialMode FlintThemeMode
Theme mode used for the base :root tokens.
final
initialTheme FlintTheme
Theme selected by initialMode.
no setter
light FlintTheme
Light theme tokens.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited