GeoPosition class
A browser geolocation position.
Constructors
- GeoPosition({required GeoCoordinates coords, required DateTime timestamp})
-
const
Properties
- accuracy → double
-
Shortcut for
coords.accuracy.no setter - coords → GeoCoordinates
-
Coordinates reported by the browser.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude → double
-
Shortcut for
coords.latitude.no setter - longitude → double
-
Shortcut for
coords.longitude.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
Time the browser captured the position.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited