HeadTag class
Describes a browser <head> tag managed by Flint UI.
Constructors
Properties
- content → String?
-
Optional text content for tags such as
scriptandstyle.final - hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Stable key used to update or replace matching head elements.
no setter
-
props
→ Map<
String, Object?> -
Attributes applied to the head element.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
Tag name, such as
meta,link,script, orstyle.final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited