HtmlContent class
Server-safe HTML content component.
- Inheritance
-
- Object
- FlintNode
- FlintComponent
- StatefulComponent
- HtmlContent
Constructors
Properties
- className ↔ String?
-
getter/setter pair
- dartStyle ↔ DartStyle?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- html ↔ String
-
getter/setter pair
- id ↔ String?
-
getter/setter pair
- preserveState → bool
-
Whether Flint should preserve this component instance across parent
rerenders when the runtime type and tree position match.
no setterinherited
-
props
↔ Map<
String, Object?> -
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector ↔ String?
-
getter/setter pair
- trusted ↔ bool
-
getter/setter pair
Methods
-
attach(
void scheduleRender()) → void -
Attaches the render scheduler used by setState.
inherited
-
build(
) → View? -
Builds this component's renderable output.
override
-
didMount(
) → void -
Called after the component is first mounted in the browser.
inherited
-
didUpdate(
) → void -
Called after the component updates following a rerender.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setState(
FlintStateUpdater update) → void -
Applies
updateand schedules this component to render again.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
updateFrom(
covariant FlintComponent next) → void -
Receives the next component instance when Flint preserves this instance.
inherited
-
willUnmount(
) → void -
Called before the component is removed from the tree.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited