Image class
Responsive img element with common loading and decoding attributes.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- Image
Constructors
-
Image({required String src, String alt = '', Object? width, Object? height, String? srcSet, String? sizes, ImageLoading loading = ImageLoading.lazy, ImageDecoding decoding = ImageDecoding.async, String? fetchPriority, String? referrerPolicy, String? crossOrigin, String? className, Map<
String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) -
Creates an image from
srcwith accessibility and loading options.
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited