JustifyContent enum
CSS justify-content values.
Values
- start → const JustifyContent
-
CSS
flex-start.const JustifyContent('flex-start') - center → const JustifyContent
-
CSS
center.const JustifyContent('center') - end → const JustifyContent
-
CSS
flex-end.const JustifyContent('flex-end') - between → const JustifyContent
-
CSS
space-between.const JustifyContent('space-between') - around → const JustifyContent
-
CSS
space-around.const JustifyContent('space-around') - evenly → const JustifyContent
-
CSS
space-evenly.const JustifyContent('space-evenly')
Properties
- css → String
-
CSS keyword emitted for this value.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
JustifyContent> - A constant List of the values in this enum, in order of their declaration.