KeyframeStep class
One step in a CSS @keyframes animation.
Constructors
- KeyframeStep(Object offset, DartStyle style)
-
Creates a keyframe step at
offset.const - KeyframeStep.from(DartStyle style)
-
Creates a
fromkeyframe step.const - KeyframeStep.percent(num percent, DartStyle style)
-
Creates a percentage keyframe step.
const
- KeyframeStep.to(DartStyle style)
-
Creates a
tokeyframe step.const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- offset → Object
-
Step offset such as
from,to, or a percentage.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selector → String
-
CSS selector for this keyframe step.
no setter
- style → DartStyle
-
Style declarations for this keyframe step.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited