LineChart class
A customizable SVG-based Line Chart widget for displaying trends.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- LineChart
Constructors
-
LineChart({required List<
double> data, required List<String> labels, double height = 200.0, String strokeColor = '#6366f1', String fillColor = 'rgba(99, 102, 241, 0.08)', double strokeWidth = 2.5, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle})
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited