Node typedef
Node = FlintNode
Short public alias for FlintNode in app code and examples.
Prefer returning View in Component build methods instead of Node to support returning raw text, lists, or other components.
Implementation
typedef Node = FlintNode;