PageShell class
Full-page layout with optional navigation, header, content, and footer.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- PageShell
Constructors
-
PageShell({Object? header, Object? child, List<
Object?> children = const [], Object maxWidth = 1200, Object padding = 24, Object gap = 32, bool safeArea = true, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle, DartStyle? contentDartStyle}) - Creates a centered page shell with configurable spacing and safe area.
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited