QueryParams class

Constructors

QueryParams()
const

Properties

all Map<String, String>
no setter
allValues Map<String, List<String>>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear({bool push = false, Object? state}) → void
get(String key) String?
getAll(String key) List<String>
has(String key) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
remove(String key, {bool push = false, Object? state}) → void
set(String key, Object? value, {bool push = false, Object? state}) → void
toString() String
A string representation of this object.
inherited
update(Map<String, Object?> values, {bool push = false, Object? state}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited