ResourceView<T> class

Rebuilds when a ResourceController changes.

Inheritance

Constructors

ResourceView(ResourceController<T> resource, ResourceBuilder<T> builder)
Creates a resource view.

Properties

builder ResourceBuilder<T>
Builder that receives the current snapshot.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
resource ResourceController<T>
Resource controller to observe.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

attach(void scheduleRender()) → void
Attaches the render scheduler used by setState.
inherited
build() View?
Builds this component's renderable output.
override
didMount() → void
Called after the component is first mounted in the browser.
inherited
didUpdate() → void
Called after the component updates following a rerender.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setState(FlintStateUpdater update) → void
Applies update and schedules this component to render again.
inherited
toString() String
A string representation of this object.
inherited
updateFrom(covariant ResourceView<T> next) → void
Receives the next component instance when Flint preserves this instance.
override
willUnmount() → void
Called before the component is removed from the tree.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited