RootDesign class
Global design CSS for root, document, and app-wide selectors.
Constructors
-
RootDesign({String name = 'root', FlintTheme? theme, DartStyle? root, DartStyle? html, DartStyle? body, DartStyle? all, DartStyle? links, Map<
String, DartStyle> selectors = const {}, List<StyleKeyframes> keyframes = const []}) -
Creates a global root design.
const
Properties
- all → DartStyle?
-
Styles emitted for the universal
*selector.final - body → DartStyle?
-
Styles emitted for the
bodyselector.final - cssText → String
-
Compiled global CSS text.
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- html → DartStyle?
-
Styles emitted for the
htmlselector.final -
keyframes
→ List<
StyleKeyframes> -
Global keyframes emitted with the root design.
final
- links → DartStyle?
-
Styles emitted for the
aselector.final - name → String
-
Unique name used when registering this root design.
final
- root → DartStyle?
-
Styles emitted for the
:rootselector.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectors
→ Map<
String, DartStyle> -
Additional global selectors and their styles.
final
- theme → FlintTheme?
-
Optional theme whose tokens are emitted as CSS variables.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited