SelectOption class
Option rendered inside a Select field.
Constructors
- SelectOption({required String label, required Object value, bool disabled = false})
-
Creates a select option.
const
Properties
- disabled → bool
-
Whether this option should be unavailable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
Visible option label.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → Object
-
Submitted option value.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited