Shadow class
Typed CSS box-shadow value.
Constructors
Properties
- blur → Object
-
Shadow blur radius.
final
- color → Object
-
Shadow color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inset → bool
-
Whether the shadow is inset.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spread → Object
-
Shadow spread radius.
final
- x → Object
-
Horizontal shadow offset.
final
- y → Object
-
Vertical shadow offset.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toCss(
) → String -
Converts this shadow to a CSS
box-shadowvalue. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited