SidebarItem class
Navigation item rendered by Sidebar.
Constructors
Properties
- active → bool
-
Whether this item is currently selected.
final
- className → String?
-
Additional CSS class for the item link.
final
- dartStyle → DartStyle?
-
Additional typed styles for the item link.
final
- disabled → bool
-
Whether this item should render as unavailable.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- href → String
-
Destination URL for the navigation link.
final
- icon → Object?
-
Optional leading icon or element.
final
- label → String
-
Visible text shown for the navigation link.
final
-
props
→ Map<
String, Object?> -
Additional element props for the item link.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
style
→ Map<
String, Object?> -
Additional inline styles for the item link.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited