StyleKeyframes class
CSS @keyframes animation built from typed style steps.
Constructors
-
StyleKeyframes(String name, List<
KeyframeStep> steps) -
Creates keyframes from a
nameandsteps.const - StyleKeyframes.fromTo({required String name, required DartStyle from, required DartStyle to})
-
Creates keyframes with
fromandtosteps.factory
Properties
- cssText → String
-
Compiled CSS
@keyframestext.no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Animation name.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
steps
→ List<
KeyframeStep> -
Ordered keyframe steps.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fadeIn(
{String name = 'flint-fade-in'}) → StyleKeyframes - Creates a reusable fade-in animation.
-
spin(
{String name = 'flint-spin'}) → StyleKeyframes - Creates a reusable rotate animation.