ThemeToken class
Convenience factories for common theme token namespaces.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
color(
String name, {Object? fallback}) → TokenRef - References a color token.
-
font(
String name, {Object? fallback}) → TokenRef - References a font token.
-
radius(
String name, {Object? fallback}) → TokenRef - References a radius token.
-
shadow(
String name, {Object? fallback}) → TokenRef - References a shadow token.
-
space(
String name, {Object? fallback}) → TokenRef - References a spacing token.