Grid class
CSS grid container with strongly typed template and alignment controls.
- Inheritance
-
- Object
- FlintNode
- FlintElement
- Grid
Constructors
-
Grid({Object? child, List<
Object?> children = const [], Object? columns, Object? sm, Object? md, Object? lg, Object? xl, Object? rows, Object? gap, String? alignItems, String? justifyItems, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) - Creates a grid around child content.
-
Grid.count(int count, {Object? child, List<
Object?> children = const [], Object? sm, Object? md, Object? lg, Object? xl, Object? gap, String? alignItems, String? justifyItems, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) -
Creates an equal-column grid (e.g.
Grid.count(3, sm: 1, md: 2, gap: 20, children: [...])).factory -
Grid.fill(Object minWidth, {Object? child, List<
Object?> children = const [], Object? sm, Object? md, Object? lg, Object? xl, Object? gap, String? alignItems, String? justifyItems, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) -
Creates a responsive auto-filling grid (e.g.
Grid.fill(200, gap: 16, children: [...])).factory -
Grid.fit(Object minWidth, {Object? child, List<
Object?> children = const [], Object? sm, Object? md, Object? lg, Object? xl, Object? gap, String? alignItems, String? justifyItems, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) -
Creates a responsive auto-fitting grid (e.g.
Grid.fit(250, gap: 20, children: [...])).factory -
Grid.ratios(List<
num> fractions, {Object? child, List<Object?> children = const [], Object? sm, Object? md, Object? lg, Object? xl, Object? gap, String? alignItems, String? justifyItems, String? className, Map<String, Object?> props = const {}, Map<String, Object?> style = const {}, DartStyle? dartStyle}) -
Creates a proportional column grid (e.g.
Grid.ratios([1, 2, 1], gap: 20, children: [...])).factory -
Creates a sidebar + fluid main content grid (e.g.
Grid.sidebar(248, gap: 20, children: [...])).factory
Properties
-
children
→ List<
FlintNode> -
Child nodes rendered inside the element.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ Map<
String, Object?> -
Element attributes, event handlers, classes, and styles.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tag → String
-
HTML tag name for this element.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited