GridCols class abstract
Clean, type-safe builder for CSS Grid columns without raw strings or nested objects.
Constructors
- GridCols()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
contentSidebar(
Object sidebarMin) → GridTemplateColumns - Creates a content area + minimum sidebar width grid layout.
-
count(
int count) → GridTemplateColumns -
Creates a template with
countequal-width fluid columns (e.g.GridCols.count(3)). -
fill(
Object minWidth, {Object max = GridTrack.oneFr}) → GridTemplateColumns -
Creates a responsive auto-fill grid with
minWidthper item (e.g.GridCols.fill(200)). -
fit(
Object minWidth, {Object max = GridTrack.oneFr}) → GridTemplateColumns -
Creates a responsive auto-fit grid with
minWidthper item (e.g.GridCols.fit(250)). -
ratios(
List< num> fractions) → GridTemplateColumns -
Creates columns based on proportional ratios (e.g.
GridCols.ratios([1, 2, 1])). -
repeat(
Object count, Object track) → GridTemplateColumns -
Creates a repeated track grid template (e.g.
GridCols.repeat(3, '200px')). -
Creates a sidebar + main content area grid (e.g.
GridCols.sidebar(248)).